<?php
/*
ipn.php - example code used for the tutorial:

PayPal IPN with PHP
How To Implement an Instant Payment Notification listener script in PHP
http://www.micahcarrick.com/paypal-ipn-with-php.html

(c) 2011 - Micah Carrick
*/

// tell PHP to log errors to ipn_errors.log in this directory
ini_set('log_errors', true);
ini_set('error_log', dirname(__FILE__).'/ipn_errors.log');

// intantiate the IPN listener
include('../includes/inc.config.php');
include('lib.functions.php');
include('ipnlistener.php');
$listener = new IpnListener();

if (isset($_GET['type']) && ($_GET['type'] == 'pp')){

// tell the IPN listener to use the PayPal test sandbox
$listener->use_sandbox = settings('pp_sandbox');

// try to process the IPN POST
try {
    $listener->requirePostMethod();
    $verified = $listener->processIpn();
} catch (Exception $e) {
    error_log($e->getMessage());
    exit(0);
}
if ($verified) {

    $errmsg = '';   // stores errors from fraud checks
    
    // 1. Make sure the payment status is "Completed" 
    if ($_POST['payment_status'] != 'Completed') { 
        // simply ignore any IPN that is not completed
        exit(0); 
    }

    // 2. Make sure seller email matches your primary account email.
    if ($_POST['receiver_email'] != settings('admin_pp')) {
        $errmsg .= "'receiver_email' does not match: ";
        $errmsg .= $_POST['receiver_email']."\n";
    }
    
    
    // 4. Make sure the currency code matches
    if ($_POST['mc_currency'] != call_curency()) {
        $errmsg .= "'mc_currency' does not match: ";
        $errmsg .= $_POST['mc_currency']."\n";
    }

    // 5. Ensure the transaction is not a duplicate.

    $txn_id = mysql_real_escape_string($_POST['txn_id']);
    $sql = "SELECT COUNT(*) FROM deposits WHERE tranzaction_id = '$txn_id'";
    $r = mysql_query($sql);
    
    if (!$r) {
        error_log(mysql_error());
        exit(0);
    }
    
    $exists = mysql_result($r, 0);
    mysql_free_result($r);
    
    if ($exists) {
        $errmsg .= "'txn_id' has already been processed: ".$_POST['txn_id']."\n";
    }
    
    if (!empty($errmsg)) {
    
        // manually investigate errors from the fraud checking
        $body = "IPN failed fraud checks: \n$errmsg\n\n";
        $body .= $listener->getTextReport();
        mail(settings('admin_email'), 'IPN Fraud Warning', $body);
        
    } else {
    
        // add this order to a table of completed orders
        $payer_email = mysql_real_escape_string($_POST['payer_email']);
        $mc_gross = mysql_real_escape_string($_POST['mc_gross']);
		$custom = mysql_real_escape_string($_POST['custom']);
		$prepare = explode('|',$custom);
		$user_id = $prepare[0];
        $ref_name = $prepare[1];
		$type = 'Deposit';
		$ref_price = (settings('aff_cut') / 100) * number_format($mc_gross,2);
		$sql = mysql_query("INSERT INTO deposits(`tranzaction_id`, `date`, `amount`, `user_id`, `procesor`, `status`) 
		                     VALUES ('$txn_id', '".time()."', '$mc_gross', '$custom', 'PayPal', '1')");
		$client = mysql_query("SELECT * FROM customers where id = '$custom'");
		while($row = mysql_fetch_array($client)){
		$bmain = $row['dep_balance'];
		}
		$new_bmain =  $bmain + $mc_gross;
        $update_client = mysql_query("UPDATE customers SET `dep_balance` = '$new_bmain' where `id` = '$custom'");
		
		if($ref_name != ''){
		$refferal = mysql_query("SELECT * FROM customers where username = '$ref_name'");
		while($aff = mysql_fetch_array($refferal)){
		$ref_bmain = $aff['main_balance'];
		}
		$new_ref_bmain =  $ref_bmain + $ref_price;
		$update_ref = mysql_query("UPDATE customers SET `dep_balance` = '$new_ref_bmain' where `username` = '$ref_name'");
		$add_commission = mysql_query("INSERT INTO commissions(`type`, `user_id`, `item_id`, `item_price`, `commission`, `indate`) 
		                                               VALUES ('$type', '$user_id', '0', '$mc_gross', '$ref_price', '".time()."')");
		}
        if (!mysql_query($sql)) {
            error_log(mysql_error());
            exit(0);
        }
        
        // send user an email with a link to their digital download
        $to = filter_var(client_data($custom,'email'), FILTER_SANITIZE_EMAIL);
        $subject = "Checkout your main balance";
        mail($to, "Thank you for your order", "You can now use your main balance to purchase your products or services. Thank you! <a href='http://".$_SERVER['SERVER_NAME']."/customers'>".settings('website_title')."</a>");
   		
		$body = "New payment recived from ".client_data($custom,'username').", ".client_data($custom,'email')."\n\n";
        //$body .= $listener->getTextReport();
        mail(settings('admin_email'), 'New payment recived!', $body);

   }
    
} else {
    // manually investigate the invalid IPN
    mail(settings('admin_email'), 'Invalid IPN', $listener->getTextReport());
}

}else if (isset($_GET['type']) && ($_GET['type'] == 'order')){

// tell the IPN listener to use the PayPal test sandbox
$listener->use_sandbox = settings('pp_sandbox');

// try to process the IPN POST
try {
    $listener->requirePostMethod();
    $verified = $listener->processIpn();
} catch (Exception $e) {
    error_log($e->getMessage());
    exit(0);
}
if ($verified) {

    $errmsg = '';   // stores errors from fraud checks
    
    // 1. Make sure the payment status is "Completed" 
    if ($_POST['payment_status'] != 'Completed') { 
        // simply ignore any IPN that is not completed
        exit(0); 
    }

    // 2. Make sure seller email matches your primary account email.
    if ($_POST['receiver_email'] != settings('admin_pp')) {
        $errmsg .= "'receiver_email' does not match: ";
        $errmsg .= $_POST['receiver_email']."\n";
    }
    
    
    // 4. Make sure the currency code matches
    if ($_POST['mc_currency'] != call_curency()) {
        $errmsg .= "'mc_currency' does not match: ";
        $errmsg .= $_POST['mc_currency']."\n";
    }

    // 5. Ensure the transaction is not a duplicate.

    $txn_id = mysql_real_escape_string($_POST['txn_id']);
    $sql = "SELECT COUNT(*) FROM tranzactions WHERE txn = '$txn_id'";
    $r = mysql_query($sql);
    
    if (!$r) {
        error_log(mysql_error());
        exit(0);
    }
    
    $exists = mysql_result($r, 0);
    mysql_free_result($r);
    
    if ($exists) {
        $errmsg .= "'txn_id' has already been processed: ".$_POST['txn_id']."\n";
    }
    
    if (!empty($errmsg)) {
    
        // manually investigate errors from the fraud checking
        $body = "IPN failed fraud checks: \n$errmsg\n\n";
        $body .= $listener->getTextReport();
        mail(settings('admin_email'), 'IPN Fraud Warning', $body);
        
    } else {
    
        // add this order to a table of completed orders
        $payer_email = mysql_real_escape_string($_POST['payer_email']);
        $mc_gross = mysql_real_escape_string($_POST['mc_gross']);
		$custom = mysql_real_escape_string($_POST['custom']);
		$prepare = explode('|',$custom);
		$user_id = $prepare[0];
        $item_id = $prepare[1];
		$auth_id = $prepare[2];
		$ref_name = $prepare[3];
		$type = 'Order';
		$author_price = (settings('cut') / 100) * number_format($mc_gross,2);
		$ref_price = (settings('aff_cut') / 100) * number_format($mc_gross,2);
		$sql = mysql_query("INSERT INTO tranzactions(`txn`, `item_id`, `for_id`, `from_id`, `indate`, `price`, `author_price`, `status`) 
		                     VALUES ('$txn_id', '$item_id', '$auth_id', '$user_id', '".time()."', '$mc_gross', '$author_price', '1')");
		$client = mysql_query("SELECT * FROM customers where id = '$auth_id'");
		while($row = mysql_fetch_array($client)){
		$bmain = $row['main_balance'];
		}
		$new_bmain =  $bmain + $author_price;	
        $update_client = mysql_query("UPDATE customers SET `dep_balance` = '$new_bmain' where `id` = '$auth_id'");
		
		if($ref_name != ''){
		$refferal = mysql_query("SELECT * FROM customers where username = '$ref_name'");
		while($aff = mysql_fetch_array($refferal)){
		$ref_bmain = $aff['main_balance'];
		}
		$new_ref_bmain =  $ref_bmain + $ref_price;
		$update_ref = mysql_query("UPDATE customers SET `dep_balance` = '$new_ref_bmain' where `username` = '$ref_name'");
		$add_commission = mysql_query("INSERT INTO commissions(`type`, `user_id`, `item_id`, `item_price`, `commission`, `indate`) 
		                                               VALUES ('$type', '$user_id', '$item_id', '$mc_gross', '$ref_price', '".time()."')");
		}
        if (!mysql_query($sql)) {
            error_log(mysql_error());
            exit(0);
        }
        
        // send user an email with a link to their digital download
        $to = filter_var(client_data($user_id,'email'), FILTER_SANITIZE_EMAIL);
        $subject = "Checkout your main balance";
        mail($to, "Thank you for your order", "You can now use your main balance to purchase your products or services. Thank you! <a href='http://".$_SERVER['SERVER_NAME']."/customers'>".settings('website_title')."</a>");
   		
		$body = "New payment recived from ".client_data($user_id,'username').", ".client_data($custom,'email')."\n\n";
        //$body .= $listener->getTextReport();
        mail(settings('admin_email'), 'New payment recived!', $body);
		
		$body2 = "New payment recived on ZoneCoders from ".client_data($user_id,'username').", ".client_data($user_id,'email')."\n\n";
        //$body .= $listener->getTextReport();
        mail(client_data($auth_id,'username'), 'New payment recived!', $body);

   }
    
} else {
    // manually investigate the invalid IPN
    mail(settings('admin_email'), 'Invalid IPN', $listener->getTextReport());
}
}else if (isset($_GET['type']) && ($_GET['type'] == 'mb')){
$user_id = $_POST['user_id'];
$ref_name = $_POST['ref_name'];
$mc_gross = $_POST['mb_amount'];
$type = 'Deposit';
$ref_price = (settings('aff_cut') / 100) * number_format($mc_gross,2);
// Validate the Moneybookers signature
$concatFields = $_POST['merchant_id']
    .$_POST['transaction_id']
    .strtoupper(md5(settings('mb_secret')))
    .$_POST['mb_amount']
    .$_POST['mb_currency']
    .$_POST['status'];

$MBEmail = settings('admin_mb');

// Ensure the signature is valid, the status code == 2,
// and that the money is going to you
if (strtoupper(md5($concatFields)) == $_POST['md5sig']
    && $_POST['status'] == 2
    && $_POST['pay_to_email'] == $MBEmail)
{
    // Valid transaction.
		$sql = mysql_query("INSERT INTO deposits(`tranzaction_id`, `date`, `amount`, `user_id`, `procesor`, `status`) 
		                                 VALUES ('".$_POST['transaction_id']."', '".time()."', '".$_POST['mb_amount']."', '".$user_id."', 'MoneyBookers', '1')");

							 
		$client = mysql_query("SELECT * FROM customers where id = '".$user_id."'");
		while($row = mysql_fetch_array($client)){
		$bmain = $row['dep_balance'];
		}
		$new_bmain =  $bmain + $mc_gross;
        $update_client = mysql_query("UPDATE customers SET `dep_balance` = '$new_bmain' where `id` = '".$user_id."'");
		
		if($ref_name != ''){
		$refferal = mysql_query("SELECT * FROM customers where username = '$ref_name'");
		while($aff = mysql_fetch_array($refferal)){
		$ref_bmain = $aff['main_balance'];
		}
		$new_ref_bmain =  $ref_bmain + $ref_price;
		$update_ref = mysql_query("UPDATE customers SET `dep_balance` = '$new_ref_bmain' where `username` = '$ref_name'");
		$add_commission = mysql_query("INSERT INTO commissions(`type`, `user_id`, `item_id`, `item_price`, `commission`, `indate`) 
		                                               VALUES ('$type', '$user_id', '0', '$mc_gross', '$ref_price', '".time()."')");
		}
		
		// send user an email with a link to their digital download
        $to = filter_var(client_data($_POST['customer_id'],'email'), FILTER_SANITIZE_EMAIL);
        $subject = "Checkout your main balance";
        mail($to, "Thank you for your order", "You can now use your main balance to purchase your products or services. Thank you! <a href='http://".$_SERVER['SERVER_NAME']."/customers'>".settings('website_title')."</a>");
		
		$body = "New payment recived from ".client_data($_POST['customer_id'],'username').", ".client_data($_POST['customer_id'],'email')."\n\n";
        $body .= $listener->getTextReport();
        mail(settings('admin_email'), 'New payment recived!', $body);
}
else
{
    // Invalid transaction. Bail out
		 $body = "MoneyBookers IPN Tranzaction failed: Tranzaction Id: ".$_POST['transaction_id']."";
        //$body .= $listener->getTextReport();
        mail(settings('admin_email'), 'MoneyBookers IPN Tranzaction Failed', $body);
    exit;
}
}
?>